@@ -3,10 +3,11 @@ from .parselite import parse
 from .visionlite import wlsplit,wlanswer,wltopk,wlsimchunks
 
 
-from .common import web,compress,get_summaries,compress_sequential,summary
+from .common import web,compress,get_summaries,compress_sequential,summary,web_top_chunk
+from .utils import relevant_chunk,get_query_relevant_chunks_list
 
 from .gmaillite import GmailAutomation,gmail,automail
 
-from .project_to_prompt import ProjectToPrompt,project_to_markdown
+from .project_to_prompt import project_to_prompt,project_to_markdown,ProjectToPrompt
 
 from .arxivlite import get_todays_arxiv_papers,research_paper_analysis
\ No newline at end of file
