@@ -5,10 +5,29 @@ from liteutils import read_arxiv
 from .searchlite import google
 from .parselite import parse
 from .visionlite import wlanswer,wlsplit
-from litegen import genai
+from litegen import LLM
 
 
 def web(
+    query: str,
+    max_urls: int = 1,
+):
+    """
+    Fetches and parses web content based on a query.
+
+    Args:
+        query (str): The search query to fetch web content for.
+        max_urls (int): The maximum number of URLs to fetch content from. Defaults to 1.
+
+    Returns:
+        str: A string containing the parsed content from the fetched web pages.
+    """
+    docs = parse(google(query, max_urls=max_urls))
+    context = "\n".join([d.content for d in docs if d.content])
+    return context
+
+
+def web_top_chunk(
     query: str,
     retreive_query: str = None,
     max_urls: int = 1,
@@ -24,18 +43,24 @@ def web(
     return context
 
 def compress_sequential(text, additional_prompt="",n=1):
+    genai = LLM()
     if n==0:
         return text
     chunks = wlsplit(text)
     res = ""
     for c in chunks:
-        res += genai(prompt=f"compress and have simple explanation in english with core details to takeaway, "
-                            f"note: keep python codes exactly same,"
-                            f"for normal like 100 to 10 words ration compression: [CONTENT]\n {c}")+"\n"
+        res += genai(
+            prompt=
+            # f"compress and have simple explanation in english with core details to takeaway, "
+            #                 f"note: keep python codes exactly same,"
+            #                 f"for normal like 100 to 10 words ration compression: [CONTENT]\n {c}"
+                   f"compress and have simple explanation in english with core details to takeaway, like 100 to 10 words ration compression: [CONTENT]\n {c}"
+        )+"\n"
     return compress_sequential(text,additional_prompt,n-1)
 
 
 def compress(text, additional_prompt="",n=1):
+    llm = LLM()
     if n==0:
         return text
     chunks = wlsplit(text)
@@ -43,7 +68,7 @@ def compress(text, additional_prompt="",n=1):
         # return genai(prompt=f"compress and have simple explanation in english with core details to takeaway,"
         #                     f"note: keep python codes exactly same\n {additional_prompt}"
         #                     f"for normal like 100 to 10 words ration compression: [CONTENT]\n {c}")+"\n"
-        return genai(prompt=f"compress and have simple explanation in english with core details to takeaway, like 100 to 10 words ration compression: [CONTENT]\n {c}")+"\n"
+        return llm(prompt=f"compress and have simple explanation in english with core details to takeaway, like 100 to 10 words ration compression: [CONTENT]\n {c}")+"\n"
 
     with ThreadPoolExecutor(max_workers=4) as executor:
         res = "\n".join(list(executor.map(generate,chunks)))
