@@ -2,7 +2,7 @@ from litegen import completion
 from litegen.model._types import ModelType
 import concurrent.futures
 
-from backup.visionlite.prompts import SEARCH_QUERY_VARATIONS_GEN_PROMPT
+from .visionlite.prompts import SEARCH_QUERY_VARATIONS_GEN_PROMPT
 
 
 def generate_k(query, k: int, **kwargs) -> list:
